
![build/test status](https://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-c-extensions%2Fmain&subject=build/tests)
[![Python Version](https://img.shields.io/pypi/pyversions/wasp-c-extensions.svg)](https://pypi.python.org/pypi/wasp-c-extensions)

A library with bunch of CPython extensions



